==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/dhcpd/dhcpd.pm <==
/* _dict.cc 29/11/1997 12.04.48 */
/* dhcpd.cc 12/12/1999 22.26.48 */
PUBLIC MODULE_DHCPD::MODULE_DHCPD (void);
PUBLIC void MODULE_DHCPD::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_DHCPD::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_DHCPD::probe (int level, int , bool);
PUBLIC void MODULE_DHCPD::usage (SSTRINGS&tb);
PUBLIC int MODULE_DHCPD::execmain (int argc, char *argv[]);
/* dhcpedit.cc 29/12/1999 23.15.54 */
PRIVATE void DHCP_OPTION::init (void);
PUBLIC DHCP_OPTION::DHCP_OPTION (const char *_keyw);
PUBLIC DHCP_OPTION::DHCP_OPTION (void);
PUBLIC void DHCP_OPTION::addvalue (const char *value);
PUBLIC void DHCP_OPTION::write (const char *indent, FILE *fout);
PUBLIC DHCP_OPTION *DHCP_OPTIONS::getitem (int no);
PUBLIC DHCP_OPTION *DHCP_OPTIONS::getitem (const char *keyw);
PUBLIC void DHCP_OPTIONS::write (const char *indent, FILE *fout);
PUBLIC void DHCP_OPTIONS::fill (void);
PUBLIC void DHCP_OPTIONS::unfill (void);
PUBLIC DHCP_RANGE::DHCP_RANGE (void);
PUBLIC DHCP_RANGE::DHCP_RANGE (char _dyn_bootp,
	 SSTRING&_start,
	 SSTRING&_stop);
PUBLIC DHCP_RANGE *DHCP_RANGES::getitem (int no)const;
PUBLIC DHCP_SUBNET::DHCP_SUBNET (void);
PUBLIC void DHCP_SUBNET::write (FILE *fout);
PUBLIC DHCP_SUBNET *DHCP_SUBNETS::getitem (int no);
PUBLIC void DHCP_SUBNETS::write (FILE *fout);
PUBLIC void DHCP_HOST::write (const char *indent, FILE *fout);
PUBLIC DHCP_HOST *DHCP_HOSTS::getitem (int no);
PUBLIC void DHCP_HOSTS::write (const char *indent, FILE *fout);
PUBLIC void DHCP_BOOTP::write (FILE *fout);
PUBLIC DHCP_BOOTP *DHCP_BOOTPS::getitem (int no);
PUBLIC int DHCP::write (void);
PRIVATE int DHCP_SUBNET::readline (DHCP_PARSE&par);
PRIVATE int DHCP_SUBNET::readlines (DHCP_PARSE&par);
PUBLIC int DHCP_SUBNET::read (DHCP_PARSE&par);
PRIVATE int DHCP::readline (DHCP_PARSE&par);
PRIVATE int DHCP::readlines (DHCP_PARSE&par);
PUBLIC DHCP::DHCP (void);
PUBLIC void DHCP_OPTIONS::setdia (DIALOG&dia);
PUBLIC int DHCP_SUBNET::edit (void);
PRIVATE int DHCP::editdefaults (void);
PUBLIC void DHCP::editloop (void);
PUBLIC void DHCP::edit (void);
PUBLIC int DHCP::probe (void);
/* hubert.cc 29/12/1999 23.15.54 */
PUBLIC UWE_RANGE::UWE_RANGE (const SSTRING&_lo, const SSTRING&_hi);
PUBLIC int UWE_RANGE::inrange (IP_ADDR *ipa);
PUBLIC UWE_RANGES::UWE_RANGES (DHCP&dh);
PUBLIC UWE_RANGE *UWE_RANGES::getitem (int no);
PUBLIC int UWE_RANGES::inrange (IP_ADDRS&ips);
/* leases.cc 29/12/1999 23.15.54 */
PUBLIC LEASE::LEASE (const char *_host,
	 const char *_ip,
	 const char *_mac,
	 const char *_starts,
	 const char *_ends,
	 const int _parserank);
PUBLIC LEASE *LEASES::getitem (int no)const;
PUBLIC void LEASES::markdup (void);
PUBLIC LEASES::LEASES (void);
PUBLIC void LEASES::showalloc (void);

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/dhcpd/dhcpd.pm <==
/* _dict.cc 29/11/1997 12.04.48 */
/* dhcpd.cc 21/02/2001 23.31.14 */
PUBLIC MODULE_DHCPD::MODULE_DHCPD (void);
PUBLIC void MODULE_DHCPD::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_DHCPD::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_DHCPD::probe (int level, int , bool);
PUBLIC void MODULE_DHCPD::usage (SSTRINGS&tb);
PUBLIC int MODULE_DHCPD::execmain (int argc, char *argv[], bool);
/* dhcpedit.cc 03/02/2001 15.52.06 */
PRIVATE void DHCP_OPTION::init (void);
PUBLIC DHCP_OPTION::DHCP_OPTION (const char *_keyw);
PUBLIC DHCP_OPTION::DHCP_OPTION (void);
PUBLIC void DHCP_OPTION::addvalue (const char *value);
PUBLIC void DHCP_OPTION::write (const char *indent, FILE_CFG *fout);
PUBLIC DHCP_OPTION *DHCP_OPTIONS::getitem (int no);
PUBLIC DHCP_OPTION *DHCP_OPTIONS::getitem (const char *keyw);
PUBLIC void DHCP_OPTIONS::write (const char *indent, FILE_CFG *fout);
PUBLIC void DHCP_OPTIONS::fill (void);
PUBLIC void DHCP_OPTIONS::unfill (void);
PUBLIC DHCP_RANGE::DHCP_RANGE (void);
PUBLIC DHCP_RANGE::DHCP_RANGE (char _dyn_bootp,
	 SSTRING&_start,
	 SSTRING&_stop);
PUBLIC DHCP_RANGE *DHCP_RANGES::getitem (int no)const;
PUBLIC DHCP_SUBNET::DHCP_SUBNET (void);
PUBLIC void DHCP_SUBNET::write (FILE_CFG *fout);
PUBLIC DHCP_SUBNET *DHCP_SUBNETS::getitem (int no);
PUBLIC void DHCP_SUBNETS::write (FILE_CFG *fout);
PUBLIC void DHCP_HOST::write (const char *indent, FILE_CFG *fout);
PUBLIC DHCP_HOST *DHCP_HOSTS::getitem (int no);
PUBLIC void DHCP_HOSTS::write (const char *indent, FILE_CFG *fout);
PUBLIC void DHCP_BOOTP::write (FILE_CFG *fout);
PUBLIC DHCP_BOOTP *DHCP_BOOTPS::getitem (int no);
PUBLIC int DHCP::write (void);
PRIVATE int DHCP_SUBNET::readline (DHCP_PARSE&par);
PRIVATE int DHCP_SUBNET::readlines (DHCP_PARSE&par);
PUBLIC int DHCP_SUBNET::read (DHCP_PARSE&par);
PRIVATE int DHCP::readline (DHCP_PARSE&par);
PRIVATE int DHCP::readlines (DHCP_PARSE&par);
PUBLIC DHCP::DHCP (void);
PUBLIC void DHCP_OPTIONS::setdia (DIALOG&dia);
PUBLIC void DHCP_OPTIONS::validate (int &new_nof);
PUBLIC int DHCP_SUBNET::edit (void);
PUBLIC int DHCP::editdefaults (void);
PUBLIC void DHCP::editloop (void);
PUBLIC void DHCP::edit (void);
PUBLIC int DHCP::probe (void);
PUBLIC void DHCP::editsub (DHCP_SUBNET *sub, bool isnew);
PUBLIC void DHCP::locate (const char *net, bool setting);
/* hubert.cc 29/12/1999 23.18.02 */
PUBLIC UWE_RANGE::UWE_RANGE (const SSTRING&_lo, const SSTRING&_hi);
PUBLIC int UWE_RANGE::inrange (IP_ADDR *ipa);
PUBLIC UWE_RANGES::UWE_RANGES (DHCP&dh);
PUBLIC UWE_RANGE *UWE_RANGES::getitem (int no);
PUBLIC int UWE_RANGES::inrange (IP_ADDRS&ips);
/* leases.cc 21/02/2001 23.33.26 */
PUBLIC LEASE::LEASE (const char *_host,
	 const char *_ip,
	 const char *_mac,
	 const char *_starts,
	 const char *_ends,
	 const int _parserank);
PUBLIC LEASE *LEASES::getitem (int no)const;
PUBLIC void LEASES::markdup (void);
PRIVATE void LEASES::init (FILE_CFG *fin);
PUBLIC LEASES::LEASES (void);
PUBLIC LEASES::LEASES (const char *fname);
PUBLIC void LEASES::showalloc (void);
/* api.cc 21/02/2001 23.36.18 */
